@@ -2,9 +2,9 @@ import asyncio
 import atexit
 from typing import List, NoReturn, Optional, Tuple, Union
 from .logger import AbstractLogger, LoggingLogger
-from .protocol.entities import MiraiConfig
+from .entities import MiraiConfig
 
-import graia.application.protocol.entities.event.mirai  # for init events
+import graia.application.event.mirai  # for init events
 from aiohttp import ClientSession, FormData
 from graia.broadcast import Broadcast
 from graia.broadcast.entities.event import BaseEvent
@@ -13,19 +13,18 @@ from yarl import URL
 from functools import partial
 
 from .context import enter_message_send_context
-from .protocol import UploadMethods
-from .protocol.entities.event.messages import (FriendMessage, GroupMessage,
+from .entities import UploadMethods
+from .event.messages import (FriendMessage, GroupMessage,
                                                TempMessage)
-from .protocol.entities.message import BotMessage
-from .protocol.entities.message.chain import MessageChain
-from .protocol.entities.message.elements import external
-from .protocol.entities.message.elements.internal import Image, Source
-from .protocol.entities.session import Session
-from .protocol.entities.targets.friend import Friend
-from .protocol.entities.targets.group import (Group, GroupConfig, Member,
-                                              MemberInfo)
-from .protocol.exceptions import InvaildArgument, InvaildSession
-from .protocol.utilles import (AppMiddlewareAsDispatcher, SinceVersion,
+from .message import BotMessage
+from .message.chain import MessageChain
+from .message.elements import external
+from .message.elements.internal import Image, Source
+from .session import Session
+from .friend import Friend
+from .group import (Group, GroupConfig, Member, MemberInfo)
+from .exceptions import InvaildArgument, InvaildSession
+from .utilles import (AppMiddlewareAsDispatcher, SinceVersion,
                                raise_for_return_code, requireAuthenticated)
 
 
@@ -195,14 +194,14 @@ class GraiaMiraiApplication:
         quote: Optional[Union[Source, int]] = None
     ) -> BotMessage:
         with enter_message_send_context(UploadMethods.Group):
-            async with self.session.post(self.url_gen("sendGroupMessage"), json=printer({
+            async with self.session.post(self.url_gen("sendGroupMessage"), json={
                 "sessionKey": self.connect_info.sessionKey,
                 "target": group.id if isinstance(group, Group) else group,
                 "messageChain": (await message.build()).dict()['__root__'],
                 **({
                     "quote": quote.id if isinstance(quote, Source) else quote
                 } if quote else {})
-            })) as response:
+            }) as response:
                 response.raise_for_status()
                 data = await response.json()
                 raise_for_return_code(data)
@@ -539,7 +538,7 @@ class GraiaMiraiApplication:
                     break
 
     async def launch(self):
-        from .protocol.entities.event.lifecycle import ApplicationLaunched
+        from .event.lifecycle import ApplicationLaunched
         self.logger.info("launching app...")
         await self.authenticate()
         await self.activeSession()
@@ -549,24 +548,22 @@ class GraiaMiraiApplication:
         )
 
         # 自动变化fetch方式
-        fetch_method = None
+        fetch_method = self.http_fetchmessage_poster if not self.connect_info.websocket else self.ws_all_poster
         config: MiraiConfig = await self.getConfig()
         if not self.connect_info.websocket: # 不启用 websocket
             self.logger.info("using websocket to receive event")
-            if config.enableWebsocket:
-                fetch_method = self.http_fetchmessage_poster
+            if config.enableWebsocket: # 配置中已经启用
                 await self.modifyConfig(enableWebsocket=False)
-        else:
+        else: # 启用ws
             self.logger.info("using pure websocket to receive event")
-            if not config.enableWebsocket:
-                fetch_method = self.ws_all_poster
+            if not config.enableWebsocket: # 配置中没启用
                 await self.modifyConfig(enableWebsocket=True)
 
         self.logger.info("event reveiver running...")
         return fetch_method()
 
     async def shutdown(self):
-        from .protocol.entities.event.lifecycle import ApplicationShutdowned
+        from .event.lifecycle import ApplicationShutdowned
         self.logger.info("application shutdowning...")
         await self.broadcast.layered_scheduler(
             listener_generator=self.broadcast.default_listener_generator(ApplicationShutdowned),
@@ -582,7 +579,10 @@ class GraiaMiraiApplication:
             fetch_method = loop.run_until_complete(self.launch())
             loop.run_until_complete(fetch_method)
         finally:
-            loop.run_until_complete(self.shutdown())
+            try:
+                loop.run_until_complete(self.shutdown())
+            except:
+                self.logger.error("it seems our shutdown operator has been failed...check your headless client alive.")
 
     def subscribe_atexit(self, loop=None):
         loop = loop or self.broadcast.loop
